@@ -8,7 +8,7 @@ else
     PREF_VER=2.7
 fi
 
-for PY_VER in ${PREF_VER} 2.7 2.6 2.5 2.4 2.3 2.2
+for PY_VER in ${PREF_VER} 2.7 2.6
 do
     # used in pick python to use in Builder driver makefile
     export PYTHON=$( which python${PY_VER} )
