@@ -29,6 +29,11 @@ if hasattr( types, 'StringTypes' ):
 else:
     StringTypes = [type( '' )]
 
+if hasattr( types, 'DictType' ):
+    DictType = types.DictType
+else:
+    DictType = type( {} )
+
 class CommandError( Exception ):
     def __init__( self, reason ):
         Exception.__init__( self )
@@ -139,7 +144,7 @@ if hasattr( pysvn.wc_notify_action, 'exists' ):
     wc_notify_action_map[ pysvn.wc_notify_action.merge_begin ] = 'merge_begin'
     wc_notify_action_map[ pysvn.wc_notify_action.update_replace ] = 'update_replace'
 
-
+# new in svn 1.6
 if hasattr( pysvn.wc_notify_action, 'property_added' ):
     wc_notify_action_map[ pysvn.wc_notify_action.property_added ] = 'property_added'
     wc_notify_action_map[ pysvn.wc_notify_action.property_modified ] = 'property_modified'
@@ -151,6 +156,7 @@ if hasattr( pysvn.wc_notify_action, 'property_added' ):
     wc_notify_action_map[ pysvn.wc_notify_action.tree_conflict ] = 'tree_conflict'
     wc_notify_action_map[ pysvn.wc_notify_action.failed_external ] = 'failed_external'
 
+# new in svn 1.7
 if hasattr( pysvn.wc_notify_action, 'update_started' ):
     wc_notify_action_map[ pysvn.wc_notify_action.update_started ] = 'update_started'
     wc_notify_action_map[ pysvn.wc_notify_action.update_skip_obstruction ] = 'update_skip_obstruction'
@@ -177,6 +183,22 @@ if hasattr( pysvn.wc_notify_action, 'update_started' ):
     wc_notify_action_map[ pysvn.wc_notify_action.failed_out_of_date ] = 'failed_out_of_date'
     wc_notify_action_map[ pysvn.wc_notify_action.failed_no_parent ] = 'failed_no_parent'
 
+# new in svn 1.7.1+?
+if hasattr( pysvn.wc_notify_action, 'failed_locked' ):
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_locked ] = 'failed_locked'
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_forbidden_by_server ] = 'failed_forbidden_by_server'
+    wc_notify_action_map[ pysvn.wc_notify_action.skip_conflicted ] = 'skip_conflicted'
+
+# new in svn 1.8
+if hasattr( pysvn.wc_notify_action, 'update_broken_lock' ):
+    wc_notify_action_map[ pysvn.wc_notify_action.update_broken_lock ] = 'update_broken_lock'
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_obstruction ] = 'failed_obstruction'
+    wc_notify_action_map[ pysvn.wc_notify_action.conflict_resolver_starting ] = 'conflict_resolver_starting'
+    wc_notify_action_map[ pysvn.wc_notify_action.conflict_resolver_done ] = 'conflict_resolver_done'
+    wc_notify_action_map[ pysvn.wc_notify_action.left_local_modifications ] = 'left_local_modifications'
+    wc_notify_action_map[ pysvn.wc_notify_action.foreign_copy_begin ] = 'foreign_copy_begin'
+    wc_notify_action_map[ pysvn.wc_notify_action.move_broken ] = 'move_broken'
+
 class SvnCommand:
     def __init__( self, progname ):
         self.progname = progname
@@ -246,8 +268,13 @@ class SvnCommand:
         print( 'callback_conflict_resolver' )
         for key in sorted( arg_dict.keys() ):
             value = arg_dict[ key ]
-            if type(value) not in StringTypes:
+
+            if type(value) == DictType:
+                value = '{%s}' % (', '.join( ['%r: %r' % (key, value) for key, value in sorted( value.items() )] ),)
+
+            elif type(value) not in StringTypes:
                 value = repr(value)
+
             print( '  %s: %s' % (key, value) )
 
         return pysvn.wc_conflict_choice.postpone, None, False
@@ -367,7 +394,7 @@ class SvnCommand:
     def cmd_cat( self, args ):
         revision = args.getOptionalRevision( '--revision', 'head' )
         text = self.client.cat( args.getPositionalArgs( 1, 1 )[0], revision=revision )
-        print( text.decode( 'utf-8' ) )
+        print( text.decode( 'utf-8' ).replace( '\r\n', '\n' ) )
 
     def cmd_checkout( self, args ):
         recurse = args.getBooleanOption( '--non-recursive', False )
@@ -451,7 +478,7 @@ class SvnCommand:
         diff_text = self.client.diff( tmpdir, positional_args[0], recurse=recurse,
                                             revision1=revision1, revision2=revision2,
                                             diff_options=['-u'] )
-        print( diff_text )
+        print( diff_text.replace( '\r\n', '\n' ) )
 
     def cmd_export( self, args ):
         force = args.getBooleanOption( '--force', False )
