@@ -40,7 +40,6 @@
 namespace Py
 {
 bool _CFunction_Check( PyObject *op )   { return op->ob_type == _CFunction_Type(); }
-bool _CObject_Check( PyObject *op )     { return op->ob_type == _CObject_Type(); }
 bool _Complex_Check( PyObject *op )     { return op->ob_type == _Complex_Type(); }
 bool _Dict_Check( PyObject *op )        { return op->ob_type == _Dict_Type(); }
 bool _Float_Check( PyObject *op )       { return op->ob_type == _Float_Type(); }
@@ -56,7 +55,14 @@ bool _TraceBack_Check( PyObject *op )   { return op->ob_type == _TraceBack_Type(
 bool _Tuple_Check( PyObject *op )       { return op->ob_type == _Tuple_Type(); }
 bool _Type_Check( PyObject *op )        { return op->ob_type == _Type_Type(); }
 bool _Unicode_Check( PyObject *op )     { return op->ob_type == _Unicode_Type(); }
+#if PY_MAJOR_VERSION == 2
+bool _String_Check( PyObject *op )      { return op->ob_type == _String_Type(); }
+bool _Int_Check( PyObject *op )         { return op->ob_type == _Int_Type(); }
+bool _CObject_Check( PyObject *op )     { return op->ob_type == _CObject_Type(); }
+#endif
+#if PY_MAJOR_VERSION >= 3
 bool _Bytes_Check( PyObject *op )       { return op->ob_type == _Bytes_Type(); }
+#endif
 
 #if defined(PY_WIN32_DELAYLOAD_PYTHON_DLL)
 
@@ -80,7 +86,6 @@ static PyObject *ptr__Exc_KeyboardInterrupt = NULL;
 static PyObject *ptr__Exc_KeyError = NULL;
 static PyObject *ptr__Exc_LookupError = NULL;
 static PyObject *ptr__Exc_MemoryError = NULL;
-static PyObject *ptr__Exc_MemoryErrorInst = NULL;
 static PyObject *ptr__Exc_NameError = NULL;
 static PyObject *ptr__Exc_NotImplementedError = NULL;
 static PyObject *ptr__Exc_OSError = NULL;
@@ -106,11 +111,11 @@ static PyObject *ptr__PyNone = NULL;
 static PyObject *ptr__PyFalse = NULL;
 static PyObject *ptr__PyTrue = NULL;
 static PyTypeObject *ptr__CFunction_Type = NULL;
-static PyTypeObject *ptr__CObject_Type = NULL;
 static PyTypeObject *ptr__Complex_Type = NULL;
 static PyTypeObject *ptr__Dict_Type = NULL;
 static PyTypeObject *ptr__Float_Type = NULL;
 static PyTypeObject *ptr__Function_Type = NULL;
+static PyTypeObject *ptr__Bool_Type = NULL;
 static PyTypeObject *ptr__List_Type = NULL;
 static PyTypeObject *ptr__Long_Type = NULL;
 static PyTypeObject *ptr__Method_Type = NULL;
@@ -120,6 +125,15 @@ static PyTypeObject *ptr__Slice_Type = NULL;
 static PyTypeObject *ptr__TraceBack_Type = NULL;
 static PyTypeObject *ptr__Tuple_Type = NULL;
 static PyTypeObject *ptr__Type_Type = NULL;
+#if PY_MAJOR_VERSION == 2
+static PyTypeObject *ptr__Int_Type = NULL;
+static PyTypeObject *ptr__String_Type = NULL;
+static PyTypeObject *ptr__CObject_Type = NULL;
+#endif
+#if PY_MAJOR_VERSION >= 3
+static PyTypeObject *ptr__Bytes_Type = NULL;
+#endif
+
 
 static int *ptr_Py_DebugFlag = NULL;
 static int *ptr_Py_InteractiveFlag = NULL;
@@ -213,9 +227,9 @@ bool InitialisePythonIndirectInterface()
 {
     char python_dll_name[sizeof(python_dll_name_format)];
 
-    sprintf( python_dll_name, python_dll_name_format, PY_MAJOR_VERSION, PY_MINOR_VERSION );
+    _snprintf( python_dll_name, sizeof(python_dll_name_format) / sizeof(char) - 1, python_dll_name_format, PY_MAJOR_VERSION, PY_MINOR_VERSION );
 
-    python_dll = LoadLibrary( python_dll_name );
+    python_dll = LoadLibraryA( python_dll_name );
     if( python_dll == NULL )
         return false;
 
@@ -245,7 +259,6 @@ bool InitialisePythonIndirectInterface()
     ptr__Exc_KeyError           = GetPyObjectPointer_As_PyObjectPointer( "PyExc_KeyError" );
     ptr__Exc_LookupError        = GetPyObjectPointer_As_PyObjectPointer( "PyExc_LookupError" );
     ptr__Exc_MemoryError        = GetPyObjectPointer_As_PyObjectPointer( "PyExc_MemoryError" );
-    ptr__Exc_MemoryErrorInst    = GetPyObjectPointer_As_PyObjectPointer( "PyExc_MemoryErrorInst" );
     ptr__Exc_NameError          = GetPyObjectPointer_As_PyObjectPointer( "PyExc_NameError" );
     ptr__Exc_NotImplementedError= GetPyObjectPointer_As_PyObjectPointer( "PyExc_NotImplementedError" );
     ptr__Exc_OSError            = GetPyObjectPointer_As_PyObjectPointer( "PyExc_OSError" );
@@ -271,11 +284,11 @@ bool InitialisePythonIndirectInterface()
     ptr__PyTrue                 = GetPyObject_As_PyObjectPointer( "_Py_TrueStruct" );
 
     ptr__CFunction_Type         = GetPyTypeObject_As_PyTypeObjectPointer( "PyCFunction_Type" );
-    ptr__CObject_Type           = GetPyTypeObject_As_PyTypeObjectPointer( "PyCObject_Type" );
     ptr__Complex_Type           = GetPyTypeObject_As_PyTypeObjectPointer( "PyComplex_Type" );
     ptr__Dict_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyDict_Type" );
     ptr__Float_Type             = GetPyTypeObject_As_PyTypeObjectPointer( "PyFloat_Type" );
     ptr__Function_Type          = GetPyTypeObject_As_PyTypeObjectPointer( "PyFunction_Type" );
+    ptr__Bool_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyBool_Type" );
     ptr__List_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyList_Type" );
     ptr__Long_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyLong_Type" );
     ptr__Method_Type            = GetPyTypeObject_As_PyTypeObjectPointer( "PyMethod_Type" );
@@ -286,14 +299,21 @@ bool InitialisePythonIndirectInterface()
     ptr__Tuple_Type             = GetPyTypeObject_As_PyTypeObjectPointer( "PyTuple_Type" );
     ptr__Type_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyType_Type" );
     ptr__Unicode_Type           = GetPyTypeObject_As_PyTypeObjectPointer( "PyUnicode_Type" );
+#if PY_MAJOR_VERSION == 2
+    ptr__String_Type            = GetPyTypeObject_As_PyTypeObjectPointer( "PyString_Type" );
+    ptr__Int_Type               = GetPyTypeObject_As_PyTypeObjectPointer( "PyInt_Type" );
+    ptr__CObject_Type           = GetPyTypeObject_As_PyTypeObjectPointer( "PyCObject_Type" );
+#endif
+#if PY_MAJOR_VERSION >= 3
     ptr__Bytes_Type             = GetPyTypeObject_As_PyTypeObjectPointer( "PyBytes_Type" );
+#endif
     }
     catch( GetAddressException &e )
     {
-        OutputDebugString( python_dll_name );
-        OutputDebugString( " does not contain symbol ");
-        OutputDebugString( e.name );
-        OutputDebugString( "\n" );
+        OutputDebugStringA( python_dll_name );
+        OutputDebugStringA( " does not contain symbol " );
+        OutputDebugStringA( e.name );
+        OutputDebugStringA( "\n" );
 
         return false;
     }
@@ -318,7 +338,6 @@ PyObject *_Exc_KeyboardInterrupt()      { return ptr__Exc_KeyboardInterrupt; }
 PyObject *_Exc_KeyError()               { return ptr__Exc_KeyError; }
 PyObject *_Exc_LookupError()            { return ptr__Exc_LookupError; }
 PyObject *_Exc_MemoryError()            { return ptr__Exc_MemoryError; }
-PyObject *_Exc_MemoryErrorInst()        { return ptr__Exc_MemoryErrorInst; }
 PyObject *_Exc_NameError()              { return ptr__Exc_NameError; }
 PyObject *_Exc_NotImplementedError()    { return ptr__Exc_NotImplementedError; }
 PyObject *_Exc_OSError()                { return ptr__Exc_OSError; }
@@ -348,7 +367,6 @@ PyObject *_False()                      { return ptr__PyFalse; }
 PyObject *_True()                       { return ptr__PyTrue; }
 
 PyTypeObject *_CFunction_Type()         { return ptr__CFunction_Type; }
-PyTypeObject *_CObject_Type()           { return ptr__CObject_Type; }
 PyTypeObject *_Complex_Type()           { return ptr__Complex_Type; }
 PyTypeObject *_Dict_Type()              { return ptr__Dict_Type; }
 PyTypeObject *_Float_Type()             { return ptr__Float_Type; }
@@ -364,7 +382,14 @@ PyTypeObject *_TraceBack_Type()         { return ptr__TraceBack_Type; }
 PyTypeObject *_Tuple_Type()             { return ptr__Tuple_Type; }
 PyTypeObject *_Type_Type()              { return ptr__Type_Type; }
 PyTypeObject *_Unicode_Type()           { return ptr__Unicode_Type; }
+#if PY_MAJOR_VERSION == 2
+PyTypeObject *_String_Type()            { return ptr__String_Type; }
+PyTypeObject *_Int_Type()               { return ptr__Int_Type; }
+PyTypeObject *_CObject_Type()           { return ptr__CObject_Type; }
+#endif
+#if PY_MAJOR_VERSION >= 3
 PyTypeObject *_Bytes_Type()             { return ptr__Bytes_Type; }
+#endif
 
 char *__Py_PackageContext()             { return *ptr__Py_PackageContext; }
 
@@ -379,16 +404,16 @@ int &_Py_NoSiteFlag()                   { return *ptr_Py_NoSiteFlag; }
 int &_Py_VerboseFlag()                  { return *ptr_Py_VerboseFlag; }
 
 #if 0
-#define Py_INCREF(op) (				\
-	_Py_INC_REFTOTAL  _Py_REF_DEBUG_COMMA	\
-	((PyObject*)(op))->ob_refcnt++)
+#define Py_INCREF(op) (                         \
+    _Py_INC_REFTOTAL  _Py_REF_DEBUG_COMMA       \
+    ((PyObject*)(op))->ob_refcnt++)
 
-#define Py_DECREF(op)					\
-	if (_Py_DEC_REFTOTAL  _Py_REF_DEBUG_COMMA	\
-	    --((PyObject*)(op))->ob_refcnt != 0)		\
-		_Py_CHECK_REFCNT(op)			\
-	else						\
-		_Py_Dealloc((PyObject *)(op))
+#define Py_DECREF(op)                           \
+    if (_Py_DEC_REFTOTAL  _Py_REF_DEBUG_COMMA   \
+        --((PyObject*)(op))->ob_refcnt != 0)    \
+        _Py_CHECK_REFCNT(op)                    \
+    else                                        \
+        _Py_Dealloc((PyObject *)(op))
 #endif
 
 void _XINCREF( PyObject *op )
@@ -449,7 +474,6 @@ PyObject *_Exc_KeyboardInterrupt()      { return ::PyExc_KeyboardInterrupt; }
 PyObject *_Exc_KeyError()               { return ::PyExc_KeyError; }
 PyObject *_Exc_LookupError()            { return ::PyExc_LookupError; }
 PyObject *_Exc_MemoryError()            { return ::PyExc_MemoryError; }
-PyObject *_Exc_MemoryErrorInst()        { return ::PyExc_MemoryErrorInst; }
 PyObject *_Exc_NameError()              { return ::PyExc_NameError; }
 PyObject *_Exc_NotImplementedError()    { return ::PyExc_NotImplementedError; }
 PyObject *_Exc_OSError()                { return ::PyExc_OSError; }
@@ -482,7 +506,6 @@ PyObject *_False()                      { return Py_False; }
 PyObject *_True()                       { return Py_True; }
 
 PyTypeObject *_CFunction_Type()         { return &PyCFunction_Type; }
-PyTypeObject *_CObject_Type()           { return &PyCObject_Type; }
 PyTypeObject *_Complex_Type()           { return &PyComplex_Type; }
 PyTypeObject *_Dict_Type()              { return &PyDict_Type; }
 PyTypeObject *_Float_Type()             { return &PyFloat_Type; }
@@ -498,7 +521,14 @@ PyTypeObject *_TraceBack_Type()         { return &PyTraceBack_Type; }
 PyTypeObject *_Tuple_Type()             { return &PyTuple_Type; }
 PyTypeObject *_Type_Type()              { return &PyType_Type; }
 PyTypeObject *_Unicode_Type()           { return &PyUnicode_Type; }
+#if PY_MAJOR_VERSION == 2
+PyTypeObject *_String_Type()            { return &PyString_Type; }
+PyTypeObject *_Int_Type()               { return &PyInt_Type; }
+PyTypeObject *_CObject_Type()           { return &PyCObject_Type; }
+#endif
+#if PY_MAJOR_VERSION >= 3
 PyTypeObject *_Bytes_Type()             { return &PyBytes_Type; }
+#endif
 
 //
 //    wrap flags
