@@ -1,8 +1,11 @@
 #
-#   Copyright (c) 2010 Barry A. Scott
+#   Copyright (c) 2010-2011 Barry A. Scott
 #
 import os
 import sys
+import distutils
+import distutils.sysconfig
+import distutils.util
 
 _debug = False
 
@@ -276,7 +279,7 @@ class Win32CompilerMSVC90(Compiler):
         rules = []
         rules.append( 'test:: %s %s' % (python_test.getTargetFilename(), python_test.python_extension.getTargetFilename()) )
         rules.append( '\tset PYTHONPATH=obj' )
-        rules.append( '\t%%(PYTHON)s %s' % (python_test.getTargetFilename(),) )
+        rules.append( '\t%%(PYTHON)s -W default %s' % (python_test.getTargetFilename(),) )
         rules.append( '' )
 
         self.makePrint( self.expand( '\n'.join( rules ) ) )
@@ -374,7 +377,7 @@ class CompilerGCC(Compiler):
     def ruleTest( self, python_test ):
         rules = []
         rules.append( 'test:: %s %s' % (python_test.getTargetFilename(), python_test.python_extension.getTargetFilename()) )
-        rules.append( '\tPYTHONPATH=obj %%(PYTHON)s %s' % (python_test.getTargetFilename(),) )
+        rules.append( '\tPYTHONPATH=obj %%(PYTHON)s -W default %s' % (python_test.getTargetFilename(),) )
         rules.append( '' )
 
         self.makePrint( self.expand( '\n'.join( rules ) ) )
@@ -394,7 +397,7 @@ class MacOsxCompilerGCC(CompilerGCC):
         self._addVar( 'PYTHON_FRAMEWORK', '%(PYTHONDIR)s/Python' )
 
         self._addVar( 'PYTHON',         sys.executable )
-        self._addVar( 'PYTHON_INCLUDE', '%(PYTHONDIR)s/include/python%(PYTHON_VERSION)s' )
+        self._addVar( 'PYTHON_INCLUDE', '%(PYTHONDIR)s/Headers' )
 
         self._addVar( 'DEMO_DIR',       'Demo/Python%d' % (sys.version_info[0],) )
 
@@ -421,7 +424,7 @@ class LinuxCompilerGCC(CompilerGCC):
         self._addVar( 'DEMO_DIR',       'Demo/Python%d' % (sys.version_info[0],) )
 
         self._addVar( 'PYTHON_VERSION', '%d.%d' % (sys.version_info[0], sys.version_info[1]) )
-        self._addVar( 'PYTHON_INCLUDE', '%s/include/python%%(PYTHON_VERSION)s' % (sys.exec_prefix,) )
+        self._addVar( 'PYTHON_INCLUDE', distutils.sysconfig.get_python_inc() )
         self._addVar( 'CCCFLAGS',
                                         '-g '
                                         '-Wall -fPIC -fexceptions -frtti '
