@@ -285,6 +285,9 @@ public:
     Py::Object cmd_switch( const Py::Tuple& args, const Py::Dict &kws );
 #if defined( PYSVN_HAS_CLIENT_LOCK )
     Py::Object cmd_unlock( const Py::Tuple& args, const Py::Dict &kws );
+#endif
+#if defined( PYSVN_HAS_CLIENT_UPGRADE )
+    Py::Object cmd_upgrade( const Py::Tuple& args, const Py::Dict &kws );
 #endif
     Py::Object cmd_update( const Py::Tuple& args, const Py::Dict &kws );
 
@@ -718,6 +721,10 @@ extern bool is_svn_url( const std::string &path_or_url );
 
 // convert a path to what SVN likes only if its not a URL
 extern std::string svnNormalisedIfPath( const std::string &unnormalised, SvnPool &pool );
+// convert a URL to what SVN likes
+extern std::string svnNormalisedUrl( const std::string &unnormalised, SvnPool &pool );
+// convert a path to what SVN likes
+extern std::string svnNormalisedPath( const std::string &unnormalised, SvnPool &pool );
 
 // convert a path to what the native OS likes
 extern std::string osNormalisedPath( const std::string &unnormalised, SvnPool &pool );
