@@ -170,8 +170,19 @@ template <> EnumString< svn_wc_notify_action_t >::EnumString()
     add( svn_wc_notify_failed_missing, "failed_missing" );
     add( svn_wc_notify_failed_out_of_date, "failed_out_of_date" );
     add( svn_wc_notify_failed_no_parent, "failed_no_parent" );
+    add( svn_wc_notify_failed_locked, "failed_locked" );
+    add( svn_wc_notify_failed_forbidden_by_server, "failed_forbidden_by_server" );
+    add( svn_wc_notify_skip_conflicted, "skip_conflicted" );
+#endif
+#if defined( PYSVN_HAS_SVN_1_8 )
+    add( svn_wc_notify_update_broken_lock, "update_broken_lock" );
+    add( svn_wc_notify_failed_obstruction, "failed_obstruction" );
+    add( svn_wc_notify_conflict_resolver_starting, "conflict_resolver_starting" );
+    add( svn_wc_notify_conflict_resolver_done, "conflict_resolver_done" );
+    add( svn_wc_notify_left_local_modifications, "left_local_modifications" );
+    add( svn_wc_notify_foreign_copy_begin, "foreign_copy_begin" );
+    add( svn_wc_notify_move_broken, "move_broken" );
 #endif
-
 }
 
 template <> EnumString< svn_wc_status_kind >::EnumString()
@@ -355,6 +366,10 @@ template <> EnumString< svn_wc_conflict_reason_t >::EnumString()
     add( svn_wc_conflict_reason_missing, "missing" );
     // object is unversioned
     add( svn_wc_conflict_reason_unversioned, "unversioned" );
+#if defined( PYSVN_HAS_SVN_1_8 )
+    add( svn_wc_conflict_reason_moved_away, "moved_away" );
+    add( svn_wc_conflict_reason_moved_here, "moved_here" );
+#endif
 }
 
 #endif
@@ -375,6 +390,7 @@ template <> EnumString< svn_depth_t >::EnumString()
 
 #if defined( PYSVN_HAS_SVN_WC_CONFLICT_CHOICE_T )
 template <> EnumString< svn_wc_conflict_choice_t >::EnumString()
+: m_type_name( "wc_conflict_choice" )
 {
     // Don't resolve the conflict now.  Let libsvn_wc mark the path
     // 'conflicted', so user can run 'svn resolved' later.
@@ -394,6 +410,7 @@ template <> EnumString< svn_wc_conflict_choice_t >::EnumString()
 
 #if defined( PYSVN_HAS_SVN_WC_OPERATION_T )
 template <> EnumString< svn_wc_operation_t >::EnumString()
+: m_type_name( "wc_operation" )
 {
     add( svn_wc_operation_none, "none" );
     add( svn_wc_operation_update, "update" );
@@ -666,6 +683,13 @@ template <> void pysvn_enum_value< svn_wc_conflict_reason_t >::init_type(void)
 #endif
 
 #if defined( PYSVN_HAS_SVN_WC_OPERATION_T )
+template <> void pysvn_enum< svn_wc_operation_t >::init_type(void)
+{
+    behaviors().name("wc_operation");
+    behaviors().doc("wc_operation enumeration");
+    behaviors().supportGetattr();
+}
+
 template <> void pysvn_enum_value< svn_wc_operation_t >::init_type(void)
 {
     behaviors().name("wc_operation");
