@@ -16,8 +16,8 @@
 #error PyCXX version 5.3.5 is required
 #endif
 
-#if PYCXX_VERSION < PYCXX_MAKEVERSION( 5, 3, 5 )
-#error PyCXX version 5.3.5 is required
+#if PYCXX_VERSION < PYCXX_MAKEVERSION( 6, 2, 4 )
+#error PyCXX version 6.2.4 is required
 #endif
 
 #include <svn_version.h>
@@ -163,7 +163,7 @@
 #define PYSVN_HAS_CLIENT_STATUS4
 #define PYSVN_HAS_AUTH_GET_SIMPLE_PROVIDER2
 #define PYSVN_HAS_AUTH_GET_SSL_CLIENT_CERT_PW_FILE_PROVIDER2
-#define PYSVN_HAS_SVN_CLIENT_CTX_T__CONFLICT_FUNC_16
+#define PYSVN_HAS_SVN_CLIENT_CTX_T__CONFLICT_FUNC_1_6
 #define PYSVN_HAS_SVN_WC_OPERATION_T
 #define PYSVN_HAS_SVN_WC_CONFLICT_RESULT_T__SAVE_MERGED
 
@@ -172,13 +172,15 @@
 // SVN 1.7 or later
 #if (SVN_VER_MAJOR == 1 && SVN_VER_MINOR >= 7) || SVN_VER_MAJOR > 1
 #define PYSVN_HAS_SVN_1_7
+#define PYSNV_HAS_REPOS_OPEN2 1
+#define PYSNV_HAS_IO_REMOVE_FILE2 1
 #define PYSVN_HAS_CLIENT_BLAME5 QQQ
 #define PYSVN_HAS_CLIENT_COMMIT5 QQQ
 #define PYSVN_HAS_CLIENT_COPY6 QQQ
 #define PYSVN_HAS_CLIENT_DELETE4 QQQ
 #define PYSVN_HAS_CLIENT_DIFF5 QQQ
 #define PYSVN_HAS_CLIENT_DIFF_PEG5 QQQ
-#define PYSVN_HAS_CLIENT_EXPORT5 QQQ
+#define PYSVN_HAS_CLIENT_EXPORT5
 #define PYSVN_HAS_CLIENT_GET_WC_ROOT QQQ
 #define PYSVN_HAS_CLIENT_IMPORT4 QQQ
 #define PYSVN_HAS_CLIENT_INFO2_T QQQ
@@ -197,6 +199,7 @@
 #define PYSVN_HAS_CLIENT_PROPSET_REMOTE QQQ
 #define PYSVN_HAS_CLIENT_RELOCATE2 QQQ
 #define PYSVN_HAS_CLIENT_STATUS5 QQQ
+#define PYSVN_HAS_CLIENT_STATUS_T QQQ
 #define PYSVN_HAS_CLIENT_SWITCH3 QQQ
 #define PYSVN_HAS_CLIENT_UPDATE4 QQQ
 #define PYSVN_HAS_CLIENT_UPGRADE QQQ
@@ -204,11 +207,19 @@
 #define PYSVN_HAS_CLIENT_UUID_FROM_PATH2 QQQ
 #endif
 
+#if (SVN_VER_MAJOR == 1 && SVN_VER_MINOR >= 8) || SVN_VER_MAJOR > 1
+#define PYSVN_HAS_SVN_1_8
+#define PYSVN_HAS_CLIENT_GET_REPOS_ROOT 1
+#define PYSVN_HAS_CLIENT_ADD5 1
+#define PYSVN_HAS_CLIENT_CREATE_CONTEXT2 1
+#endif
 
 #if defined( PYSVN_HAS_CLIENT_STATUS3 )
 typedef svn_wc_status2_t pysvn_wc_status_t;
+
 #elif defined( PYSVN_HAS_CLIENT_STATUS2 )
 typedef svn_wc_status2_t pysvn_wc_status_t;
+
 #else
 typedef svn_wc_status_t pysvn_wc_status_t;
 #endif
