@@ -770,7 +770,6 @@ class Win32CompilerMSVC90(Compiler):
                     r'%(SVN_LIB)s\libsvn_fs-1.lib',
                     r'%(SVN_LIB)s\libsvn_fs_fs-1.lib',
                     r'%(SVN_LIB)s\libsvn_ra-1.lib',
-                    r'%(SVN_LIB)s\libsvn_ra_neon-1.lib',
                     r'%(SVN_LIB)s\libsvn_ra_local-1.lib',
                     r'%(SVN_LIB)s\libsvn_ra_svn-1.lib',
                     r'%(SVN_LIB)s\libsvn_repos-1.lib',
@@ -783,6 +782,11 @@ class Win32CompilerMSVC90(Compiler):
                     ]
         if os.path.exists( self.expand( r'%(SVN_LIB)s\serf\serf-1.lib' ) ):
             ldlibs.append( r'%(SVN_LIB)s\serf\serf-1.lib' )
+        elif os.path.exists( self.expand( r'%(SVN_LIB)s\libsvn_ra_neon-1.lib' ) ):
+            ldlibs.append( r'%(SVN_LIB)s\libsvn_ra_neon-1.lib' )
+        else:
+            raise SetupError( 'Cannot find serf or neon' )
+
         ldlibs.append( r'ws2_32.lib' )
 
         self._addVar( 'LDLIBS', ' '.join( ldlibs ) )
@@ -796,7 +800,9 @@ class Win32CompilerMSVC90(Compiler):
         v = {'TN': test_case.test_name
             ,'KGV':  'py%d-svn%d.%d' %
                         (sys.version_info[0]
-                        ,self.getSvnVersion()[0], self.getSvnVersion()[1])}
+                        ,self.getSvnVersion()[0], self.getSvnVersion()[1])
+            ,'SVN_VERSION': '%d.%d.%d' % self.getSvnVersion()
+            }
 
         rules = []
         rules.append( '' )
@@ -810,7 +816,7 @@ class Win32CompilerMSVC90(Compiler):
         rules.append( '\t' 'test-%(TN)s.cmd >test-%(TN)s.win32.new.log 2>&1' % v )
         rules.append( '' )
         rules.append( 'test-%(TN)s.win32.new.log.clean: test-%(TN)s.win32.new.log' % v )
-        rules.append( '\t' '%%(PYTHON)s benchmark_diff.py test-%(TN)s.win32.known_good-%(KGV)s.log test-%(TN)s.win32.new.log' % v )
+        rules.append( '\t' '%%(PYTHON)s benchmark_diff.py %(SVN_VERSION)s test-%(TN)s.win32.known_good-%(KGV)s.log test-%(TN)s.win32.new.log' % v )
         rules.append( '' )
         rules.append( 'clean-%(TN)s:' % v )
         rules.append( '\t' '-subst b: /d >nul 2>&1' % v )
@@ -873,7 +879,7 @@ class CompilerGCC(Compiler):
 
         rules.append( '%s : %s' % (target_filename, ' '.join( all_objects )) )
         rules.append( '\t@echo Link %s' % (target_filename,) )
-        rules.append( '\t@%%(LDSHARED)s -o %s %%(CCCFLAGS)s %s' % (target_filename, ' '.join( all_objects )) )
+        rules.append( '\t@%%(LDSHARED)s -o %s %%(CCCFLAGS)s %s %%(LDLIBS)s' % (target_filename, ' '.join( all_objects )) )
 
         self.makePrint( self.expand( '\n'.join( rules ) ) )
 
@@ -915,7 +921,10 @@ class CompilerGCC(Compiler):
         v = {'TN': test_case.test_name
             ,'KGV':  'py%d-svn%d.%d' %
                                         (sys.version_info[0]
-                                        ,self.getSvnVersion()[0], self.getSvnVersion()[1])}
+                                        ,self.getSvnVersion()[0], self.getSvnVersion()[1])
+            ,'SVN_VERSION': '%d.%d.%d' % self.getSvnVersion()
+            }
+
         rules = []
         rules.append( '' )
         rules.append( '' )
@@ -924,7 +933,7 @@ class CompilerGCC(Compiler):
         rules.append( '\t' 'LD_LIBRARY_PATH=%%(SVN_LIB)s:%%(APR_LIB)s PATH=%%(SVN_BIN)s:$(PATH) PYTHON=%%(PYTHON)s ./test-%(TN)s.sh >test-%(TN)s.unix.new.log 2>&1' % v )
         rules.append( '' )
         rules.append( 'test-%(TN)s.unix.new.log.clean: test-%(TN)s.unix.new.log' % v )
-        rules.append( '\t' '%%(PYTHON)s benchmark_diff.py test-%(TN)s.unix.known_good-%(KGV)s.log test-%(TN)s.unix.new.log' % v )
+        rules.append( '\t' '%%(PYTHON)s benchmark_diff.py %(SVN_VERSION)s test-%(TN)s.unix.known_good-%(KGV)s.log test-%(TN)s.unix.new.log' % v )
         rules.append( '' )
         rules.append( 'clean-%(TN)s:' % v )
         rules.append( '\t' '-rm -f test-%(TN)s.unix.new.log' % v )
@@ -1135,12 +1144,14 @@ class UnixCompilerGCC(CompilerGCC):
         self._addVar( 'PYSVN_MODULE_BASENAME', self.pysvn_module_name )
 
         self._addVar( 'PYTHON_VERSION', '%d.%d' % (sys.version_info[0], sys.version_info[1]) )
-        self._addVar( 'PYTHON_INC',     distutils.sysconfig.get_python_inc() )
+        self._addVar( 'PYTHON_INC',     distutils.sysconfig.get_python_inc( False ) )
+        self._addVar( 'PYTHON_ARCH_SPECIFIC_INC',     distutils.sysconfig.get_python_inc( True ) )
 
         py_cflags_list = [
                     '-Wall -fPIC -fexceptions -frtti',
                     '-I. -I%(APR_INC)s -I%(SVN_INC)s',
                     '-DPYCXX_PYTHON_2TO3 -I%(PYCXX)s -I%(PYCXX_SRC)s -I%(PYTHON_INC)s',
+                    '-I%(PYTHON_ARCH_SPECIFIC_INC)s',
                     '-D%(DEBUG)s',
                     ]
         for define, value in self.py_module_defines:
@@ -1154,7 +1165,7 @@ class UnixCompilerGCC(CompilerGCC):
 
         self._addVar( 'CCCFLAGS',   ' '.join( py_cflags_list ) )
         self._addVar( 'LDLIBS',     ' '.join( self._getLdLibs() ) )
-        self._addVar( 'LDSHARED',   '%(CCC)s -shared -g %(LDLIBS)s' )
+        self._addVar( 'LDSHARED',   '%(CCC)s -shared -g' )
 
 #--------------------------------------------------------------------------------
 class LinuxCompilerGCC(UnixCompilerGCC):
