@@ -51,11 +51,16 @@ class LiteralCaseBlindSearch:
             return None
 
 class ReplaceDirtInString:
-    def __init__( self, lines_list ):
+    def __init__( self, lines_list, svn_version ):
         self.lines_list = lines_list
         self.workdir = self.find( 'WorkDir' )
         self.python = self.find( 'PYTHON' )
         self.username = self.find( 'Username' )
+        self.svn_version = svn_version
+        self.txn_replacement = None
+        if self.svn_version is not None:
+            if self.svn_version[0] > 1 or (self.svn_version[0] == 1 and self.svn_version[1] >= 8):
+                self.txn_replacement = 'svn:txn-client-compat-version: %d.%d.%d' % self.svn_version
 
         # ------------------------------------------------------------------------
         # Version strings:
@@ -97,14 +102,14 @@ class ReplaceDirtInString:
             workdir_re1 = LiteralCaseBlindSearch( self.workdir )
             workdir_re2 = LiteralCaseBlindSearch( os.path.realpath( self.workdir ) )
             self.replacement_list.append(
-                 (workdir_re1,        '<workdir>') )
+                 (workdir_re1,          '<workdir>') )
             self.replacement_list.append(
-                 (workdir_re2,        '<workdir>') )
+                 (workdir_re2,          '<workdir>') )
 
         if self.python:
             python_re = LiteralCaseBlindSearch( self.python )
             self.replacement_list.append(
-                 (python_re,        '<PYTHON>') )
+                 (python_re,            '<PYTHON>') )
 
         if True:
             # must replace username after workdir
@@ -132,6 +137,7 @@ class ReplaceDirtInString:
 
     def replace( self, line ):
         if _debug: print( 'Processing: %r' % (line,) )
+
         for re_expr, replacement_text in self.replacement_list:
             while 1:
                 if _debug: print( '...trying: %r' % (replacement_text,) )
@@ -139,17 +145,26 @@ class ReplaceDirtInString:
                 if match == None:
                     break
                 line = line[0:match.start()] + replacement_text + line[match.end():]
+
+
                 if _debug: print( '...update line: %r' % (line,) )
+
+        x = line.startswith( 'svn:txn-client-compat-version: ' )
+        if( self.txn_replacement is not None
+        and line.startswith( 'svn:txn-client-compat-version: ' ) ):
+            line = self.txn_replacement
+            if _debug: print( '...update line: %r' % (line,) )
+
         return line
 
 
-def stripDirty( filename ):
+def stripDirty( filename, svn_version ):
     f = open(filename, 'r')
     contents = f.read()
     f.close()
 
     lines = contents.replace( '\r\n', '\n' ).replace( '\r', '\n' ).split( '\n' )
-    replace = ReplaceDirtInString( lines )
+    replace = ReplaceDirtInString( lines, svn_version )
     stripped_lines = replace.execute()
 
     return stripped_lines
@@ -160,17 +175,20 @@ def stripDirty( filename ):
  
 def main( argv ):
     try:
-        benchmark_file = argv[1]
-        results_file = argv[2]
+        svn_version = tuple( [int(x) for x in argv[1].split('.')] )
+        benchmark_file = argv[2]
+        results_file = argv[3]
+
+        print( 'Info: SVN Version %d.%d.%d' % svn_version )
 
         print( 'Info: Comparing %s' % benchmark_file )
-        benchmark = stripDirty( benchmark_file )
+        benchmark = stripDirty( benchmark_file, svn_version )
         if _debug:
             print( 'Debug: benchmark after we called stripDirty' )
             pprint.pprint( benchmark )
 
         print( 'Info: Against   %s' % results_file )
-        results = stripDirty( results_file )
+        results = stripDirty( results_file, None )
         if _debug:
             print( 'Debug: results after we called stripDirty' )
             pprint.pprint( results )
