@@ -34,16 +34,16 @@ echo '#!/bin/sh' >${TESTROOT}/repos/hooks/pre-commit
 echo export PYTHONPATH=$PYTHONPATH >>${TESTROOT}/repos/hooks/pre-commit
 echo export LD_LIBRARY_PATH=$LD_LIBRARY_PATH >>${TESTROOT}/repos/hooks/pre-commit
 echo export PATH=$PATH >>${TESTROOT}/repos/hooks/pre-commit
-echo echo $PYTHON ${WORKDIR}/Tests/test_04_commit_hook_test_1.py '"$@"' ">${TESTROOT}/pre_test_1.output" >>${TESTROOT}/repos/hooks/pre-commit
-echo $PYTHON ${WORKDIR}/Tests/test_04_commit_hook_test_1.py '"$@"' ">>${TESTROOT}/pre_test_1.output" >>${TESTROOT}/repos/hooks/pre-commit
+echo echo $PYTHON ${WORKDIR}/Tests/test_04_commit_hook_test_1.py pre-commit '"$@"' ">${TESTROOT}/pre_test_1.output" >>${TESTROOT}/repos/hooks/pre-commit
+echo $PYTHON ${WORKDIR}/Tests/test_04_commit_hook_test_1.py pre-commit '"$@"' ">>${TESTROOT}/pre_test_1.output" >>${TESTROOT}/repos/hooks/pre-commit
 chmod +x ${TESTROOT}/repos/hooks/pre-commit
 
 echo '#!/bin/sh' >${TESTROOT}/repos/hooks/post-commit
 echo export PYTHONPATH=$PYTHONPATH >>${TESTROOT}/repos/hooks/post-commit
 echo export LD_LIBRARY_PATH=$LD_LIBRARY_PATH >>${TESTROOT}/repos/hooks/post-commit
 echo export PATH=$PATH >>${TESTROOT}/repos/hooks/post-commit
-echo echo $PYTHON ${WORKDIR}/Tests/test_04_commit_hook_test_1.py '"$@"' is_revision ">${TESTROOT}/post_test_1.output" >>${TESTROOT}/repos/hooks/post-commit
-echo $PYTHON ${WORKDIR}/Tests/test_04_commit_hook_test_1.py '"$@"' is_revision ">>${TESTROOT}/post_test_1.output" >>${TESTROOT}/repos/hooks/post-commit
+echo echo $PYTHON ${WORKDIR}/Tests/test_04_commit_hook_test_1.py post-commit '"$@"' is_revision ">${TESTROOT}/post_test_1.output" >>${TESTROOT}/repos/hooks/post-commit
+echo $PYTHON ${WORKDIR}/Tests/test_04_commit_hook_test_1.py post-commit '"$@"' is_revision ">>${TESTROOT}/post_test_1.output" >>${TESTROOT}/repos/hooks/post-commit
 chmod +x ${TESTROOT}/repos/hooks/post-commit
 
 cmd ${PYSVN} mkdir file://${TESTROOT}/repos/trunk/test/a -m "pre-commit test 1"
